@@ -24,12 +24,20 @@ def add_source(urls=None):
 
 
 urls = [
+    "https://cdn.jsdelivr.net/gh/bushixuanqi/book-source/%E4%B9%A6%E6%BA%90%E5%90%88%E9%9B%86.json",
+
+    "https://guaner001125.coding.net/p/coding-code-guide/d/booksources/git/raw/master/sources/guaner.json",
+    "https://haxc.coding.net/p/booksrc/d/booksrc/git/raw/master/Book3.0Source.json",
+
     "https://namofree.gitee.io/yuedu3/legado3_booksource_by_Namo.json",
-    "https://shuyuan.miaogongzi.net/shuyuan/1630342495.json",
     "https://pbpobing.coding.net/p/yueduyuan/d/sy/git/raw/master/syhj.json",
     "https://pbpobing.coding.net/p/yueduyuan/d/sy/git/raw/master/yshj.json",
-    "https://haxc.coding.net/p/booksrc/d/booksrc/git/raw/master/Book3.0Source.json",
+
+    "http://shuyuan.miaogongzi.net/shuyuan/1624832786.json",
+    "https://shuyuan.miaogongzi.net/shuyuan/1630342495.json",
+    "http://shuyuan.miaogongzi.net/shuyuan/1623355431.json",
+
     "https://tangguochaotian.coding.net/p/tangguoshuyuan1015/d/tangguo/git/raw/master/exportBookSource.json",
-    "https://guaner001125.coding.net/p/coding-code-guide/d/booksources/git/raw/master/sources/guaner.json"
+    "https://tianyuzhange.coding.net/p/booksource/d/shuyuan/git/raw/master/2.0shuyuan.json",
 ]
 add_source(urls)
